@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12989 2021-06-17 13:44:08Z Lavender $
+# $Id: __init__.py 13367 2021-12-24 04:53:31Z Mint $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2021-06-17 21:44:08 +0800 (Thu, 17 Jun 2021) $
-# $Revision: 12989 $
+# $Author: Mint $ (last)
+# $Date: 2021-12-24 12:53:31 +0800 (週五, 24 十二月 2021) $
+# $Revision: 13367 $
 
 from __future__ import print_function
 
@@ -437,6 +437,7 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
                     'PORT': _get('DATABASE_PORT'),
                 },
             },
+            'DEFAULT_AUTO_FIELD': 'django.db.models.AutoField',
         }
         if _get('OPTIONS'):
             databaseDefaults['DATABASES']['default']['OPTIONS'] = _get('OPTIONS')
@@ -654,7 +655,8 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
         'BACKEND': 'django.template.backends.django.DjangoTemplates',
         'DIRS': [os.path.join(settingsDict.get('BASE_DIR', projectPath),
                               'templates'),],
-        'APP_DIRS': True,
+        # 需要這個才能找到 site-packages 裡面的 templates
+        #'APP_DIRS': True,
         'OPTIONS': {
             'context_processors': [
                 'django.template.context_processors.debug',
