@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12825 2021-03-31 13:28:58Z Lavender $
+# $Id: __init__.py 12836 2021-04-08 06:31:19Z Lavender $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2021-03-31 21:28:58 +0800 (Wed, 31 Mar 2021) $
-# $Revision: 12825 $
+# $Date: 2021-04-08 14:31:19 +0800 (週四, 08 四月 2021) $
+# $Revision: 12836 $
 
 import logging
 import traceback
@@ -24,6 +24,7 @@ from django.core.mail.backends.base import BaseEmailBackend
 from django.core.mail.backends.smtp import EmailBackend as SmtpEmailBackend
 from django.conf import settings
 
+from Iuno.Util import update
 from Iuppiter.Encoding import utf8, _unicode
 from Iuppiter.Json import serializer
 from Iuppiter.Logging import createLogger
@@ -33,16 +34,29 @@ logger = createLogger(__name__, 'Newsletter.log')
 
 def attachSettings(settingsLocals, backends, preferred, config):
     """
-    Attach 'mail' related settings to settings.py.
+    Attach 'newsletter' related settings to settings.py.
 
     @param settingsLocals locals() in settings.py.
     @param backends Backend instances.
     @param preferred Preferred backends.
     @param config Configuration settings.
     """
+    
     extendInstalledApps(settingsLocals, (
         'Iuno.cloud.newsletter',
     ))
+    
+    DEFAULT_BOINCED_EMAIL_SUBJECTS = [
+        "Undelivered Mail Returned to Sender",
+        "Delivery Status Notification (Failure)"
+    ]
+    
+    DEFAULT_SETTINGS = {
+        'IUNO_CLOUD_NEWSLETTER_BOINCED_EMAIL_SUBJECTS': DEFAULT_BOINCED_EMAIL_SUBJECTS,
+        'IUNO_CLOUD_NEWSLETTER_BOINCED_EMAIL_SEARCH_DAYS': 1,
+    }
+    
+    update(settingsLocals, DEFAULT_SETTINGS)
 
 class EmailBackend(BaseEmailBackend):
 
@@ -146,6 +160,10 @@ class EmailBackend(BaseEmailBackend):
 
         @param email_messages Email messages.
         """
+        # filter black contact 
+        from Iuno.Email import filterBlacklist
+        email_messages = filterBlacklist(email_messages)
+        
         try:
             if self.useSmtp:
                 raise RuntimeError(
