@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12638 2020-12-17 07:19:51Z Lavender $
+# $Id: __init__.py 13035 2021-07-01 11:21:38Z Lavender $
 #
 # Copyright (c) 2016 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-12-17 15:19:51 +0800 (週四, 17 十二月 2020) $
-# $Revision: 12638 $
+# $Date: 2021-07-01 19:21:38 +0800 (週四, 01 七月 2021) $
+# $Revision: 13035 $
 
 import random
 import requests
@@ -24,6 +24,7 @@ import requests
 
 from django.template import Context, Template
 from django.conf import settings
+from django.dispatch import Signal
 from six.moves import urllib_parse, urllib_request, urllib_error
 
 from Iuno import require
@@ -38,6 +39,8 @@ def attachSettings(settingsLocals, backends, preferred, config):
     else:
         require("IUNO_CLOUD_SMS_CLIENT_TOKEN", settingsLocals) 
         
+smsAfterVerify = Signal()
+        
 DEFAULT_PREFIX_COUNT = 4
 DEFAULT_CODE_COUNT = 6
 DEFAULT_TEMPLATE = ("{%if site %}[{{ site }}]{% endif %} "
