@@ -15,10 +15,21 @@
 # $Date: 2018-07-16 18:31:00 +0900 (週一, 16 七月 2018) $
 # $Revision: 11172 $
 
+import random
+
 from django.contrib import admin
+
 from Iuno.cloud.sms.models import Token
+from Iuno.cloud.sms.forms import TokenAdminForm
 
 class TokenAdmin(admin.ModelAdmin):
-    list_display = ('username', 'token')
+    form = TokenAdminForm
+    list_display = ('name', 'username', 'token', 'description')
+    
+    def get_changeform_initial_data(self, request):
+        initialCode = "".join([random.choice('ABCDEFGHIJKLMNOPQRSTUVWXYZ') for i in range(10)])
+        return {
+            'token': initialCode,
+        }
     
 admin.site.register(Token, TokenAdmin)
\ No newline at end of file
