@@ -19,9 +19,15 @@
 #  Bear
 #  Yachu
 
+import base64
+
 from django.db import models
 
 class Token(models.Model):
+    name = models.CharField(max_length=100)
     token = models.CharField(max_length=30, unique=True)
     username = models.CharField(max_length=255)
-    password = models.CharField(max_length=255)
\ No newline at end of file
+    password = models.CharField(max_length=255)
+    description = models.TextField(null=True)
+   
+        
\ No newline at end of file
