@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class MaintenanceConfig(AppConfig):
-    name = 'maintenance'
+    name = 'Iuno.maintenance'
