@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: start_project.py 12434 2020-07-29 19:01:27Z Lavender $
+# $Id: start_project.py 13367 2021-12-24 04:53:31Z Mint $
 #
 # Copyright (c) 2016 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,19 +11,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2020-07-30 03:01:27 +0800 (週四, 30 七月 2020) $
-# $Revision: 12434 $
+# $Author: Mint $
+# $Date: 2021-12-24 12:53:31 +0800 (週五, 24 十二月 2021) $
+# $Revision: 13367 $
 
 import os
 import sys
 import six
 import shutil
 import datetime
+#import django
 
-from django.core.management.base import BaseCommand, CommandError
+from django.core.management.base import BaseCommand, CommandError #pylint: disable=W0611
 from django.template.loader import get_template
-from django.template import Context
+from django.template import Context #pylint: disable=W0611
 
 from Iuno.Version import IUNO_VERSION
 from Iuppiter.Encoding import utf8
@@ -36,7 +37,7 @@ SCAFFOLD_TEMP_PATH = "\\Pandora\\trunk\\Containers\\Apps\\Scaffold\\_Scaffold"
 SCAFFOLD_PATH = "\\Pandora\\trunk\\Containers\\Apps\\Scaffold\\Scaffold"
 
 # http://landcareweb.com/questions/6325/python-yi-dong-bing-fu-gai-wen-jian-he-wen-jian-jia
-def forceCopyFile (sfile, dfile):
+def forceCopyFile(sfile, dfile):
     if os.path.isfile(sfile):
         shutil.copy2(sfile, dfile)
         
@@ -62,7 +63,7 @@ def copyTree(src, dst):
         if os.path.isfile(s):
             if not os.path.exists(dst):
                 os.makedirs(dst)
-            forceCopyFile(s,d)
+            forceCopyFile(s, d)
         if os.path.isdir(s):
             isRecursive = not isAFlatDir(s)
             if isRecursive:
@@ -119,13 +120,13 @@ class Command(BaseCommand):
                 "%s manage.py startproject %s \"%s\"" % (
                     sys.executable, name, path))
 
-        import django
+        
 
-        if not (
-            django.VERSION[0] == 2 and 
-            django.VERSION[1] == 2 and 
-            django.VERSION[2] == 10):
-            raise CommandError("Only support django 2.2.10")
+        #if not (
+        #    django.VERSION[0] == 2 and 
+        #    django.VERSION[1] == 2 and 
+        #    django.VERSION[2] == 10):
+        #    raise CommandError("Only support django 2.2.10")
 
         settingPath = os.path.join(path, name, 'settings.py')
         urlPath = os.path.join(path, name, 'urls.py')
@@ -248,6 +249,10 @@ class Command(BaseCommand):
         urlconf = temp.render(context)
         content = content.replace(urlconf, '')
         
+        # default auto field # TODO test if removing auto field is fine
+        temp = get_template('scaffold/DefaultAutoField.txt')
+        default_auto_field = temp.render(context)
+        content = content.replace(default_auto_field, '')
         
         # Footer
         temp = get_template('scaffold/FooterTemplate.txt')
