@@ -1,7 +1,7 @@
 #!/bin/sh
 
 if [ -z $CONDA_DEFAULT_ENV ]; then
-    conda create -p env python=3.7.3 -y
+    conda create -p env python=3.9 -y
     source env/bin/activate
     python -m pip install --upgrade pip
     pip install -r REQUIREMENTS.txt
