@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 13360 2021-11-25 10:09:45Z Tiffany $
+# $Id: __init__.py 13367 2021-12-24 04:53:31Z Mint $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Tiffany $ (last)
-# $Date: 2021-11-25 18:09:45 +0800 (週四, 25 十一月 2021) $
-# $Revision: 13360 $
+# $Author: Mint $ (last)
+# $Date: 2021-12-24 12:53:31 +0800 (週五, 24 十二月 2021) $
+# $Revision: 13367 $
 
 import os
 import re
@@ -163,7 +163,6 @@ def attachSettings(settingsDict, enablePaypal=False):
 
             # Conservative import to ensure that this file can be loaded
             # without the presence Django.
-            from django.utils import six
             if isinstance(overrides, six.string_types):
                 raise ValueError(
                     "get_core_apps expects a list or tuple of apps "
@@ -173,8 +172,22 @@ def attachSettings(settingsDict, enablePaypal=False):
                 pattern = app_label.replace('oscar.apps.', '')
                 for override in overrides:
                     if pattern.startswith(override):
+                        # EX: override='catalogue', pattern='catalogue.apps.CatalogueConfig' (正確)
+                        # EX: override='catalogue', pattern='catalogue.reviews.apps.CatalogueReviewsConfig' (不正確)
+                        # EX: override='catalogue.reviews', 
+                        #     pattern='catalogue.reviews.apps.CatalogueReviewsConfig' (正確)
+                        # 這兩個是不同的 app，但 reviews 這個 app 被放在 catalogue 中，
+                        # 需要區分是要 override catalogue 還是 reviews
+                        # 用於新版 oscar>=2.0.0
                         if 'reviews' in pattern and not 'reviews' in override:
                             continue
+                        
+                        # https://github.com/django-oscar/django-oscar/blob/releases/1.6/src/oscar/__init__.py
+                        # 這是從 oscar<2.0.0 的版本複製過來的 get_app_label function 內所寫的程式碼
+                        # 在舊版時，在這個 if 裡面是用 pattern.startswith(override)
+                        # 是用來區分 override='catalogue', pattern='dashboard.catalogue' 用的
+                        # 但這在 oscar>=2.0.0 後完全沒用了
+                        # 這部分當時因為剛做 oscar 升級到 2 時，因為還有專案是用舊版，為了做上下相容所留下來的
                         if 'dashboard' in override and 'dashboard' != pattern:
                             continue
                         return override
