@@ -3,7 +3,6 @@ from django.contrib.contenttypes import fields
 from django.contrib.contenttypes.models import ContentType
 from django.db import models
 from django.urls import reverse
-from django.utils.encoding import python_2_unicode_compatible
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import pgettext_lazy
 
@@ -39,7 +38,6 @@ class LinkedPromotion(models.Model):
     record_click.alters_data = True
 
 
-@python_2_unicode_compatible
 class PagePromotion(LinkedPromotion):
     """
     A promotion embedded on a particular page.
@@ -135,8 +133,6 @@ class AbstractPromotion(models.Model):
                                               object_id=self.id).count()
         return page_count + keyword_count
 
-
-@python_2_unicode_compatible
 class RawHTML(AbstractPromotion):
     """
     Simple promotion - just raw HTML
@@ -163,7 +159,6 @@ class RawHTML(AbstractPromotion):
         return self.name
 
 
-@python_2_unicode_compatible
 class Image(AbstractPromotion):
     """
     An image promotion is simply a named image which has an optional
@@ -190,7 +185,6 @@ class Image(AbstractPromotion):
         verbose_name_plural = _("Image")
 
 
-@python_2_unicode_compatible
 class MultiImage(AbstractPromotion):
     """
     A multi-image promotion is simply a collection of image promotions
@@ -215,7 +209,6 @@ class MultiImage(AbstractPromotion):
         verbose_name_plural = _("Multi Images")
 
 
-@python_2_unicode_compatible
 class SingleProduct(AbstractPromotion):
     _type = 'Single product'
     name = models.CharField(_("Name"), max_length=128)
@@ -235,7 +228,6 @@ class SingleProduct(AbstractPromotion):
         verbose_name_plural = _("Single product")
 
 
-@python_2_unicode_compatible
 class AbstractProductList(AbstractPromotion):
     """
     Abstract superclass for promotions which are essentially a list
