@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 12858 2021-04-23 03:51:09Z Lavender $
+# $Id: views.py 13367 2021-12-24 04:53:31Z Mint $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and 
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2021-04-23 11:51:09 +0800 (週五, 23 四月 2021) $
-# $Revision: 12858 $ 
+# $Author: Mint $
+# $Date: 2021-12-24 12:53:31 +0800 (週五, 24 十二月 2021) $
+# $Revision: 13367 $ 
 
 import json
 import logging
@@ -854,7 +854,7 @@ from oscar.apps.dashboard.orders import views as dashboardOrderViews
 from Iuno.shop.forms import OrderNoteForm
 
 OrderNote = get_model('order', 'OrderNote')
-CommunicationEventType = get_model('customer', 'CommunicationEventType')
+CommunicationEventType = get_model('communication', 'CommunicationEventType')
 Dispatcher = get_class('customer.utils', 'Dispatcher')
 
 def get_order_note_form(self):
@@ -884,7 +884,7 @@ def save_note(self, request, order):
                 'note': note,
             }
             msg = CommunicationEventType.objects.get_and_render(code, ctx)
-            Dispatcher().dispatch_order_messages(order, msg)
+            # Dispatcher().dispatch_order_messages(order, msg)
         messages.success(self.request, _("Note saved"))
         return self.reload_page(fragment='notes')
 
