@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 13367 2021-12-24 04:53:31Z Mint $
+# $Id: admin.py 13368 2022-01-01 08:52:58Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Mint $
-# $Date: 2021-12-24 12:53:31 +0800 (週五, 24 十二月 2021) $
-# $Revision: 13367 $
+# $Author: Lavender $
+# $Date: 2022-01-01 16:52:58 +0800 (週六, 01 一月 2022) $
+# $Revision: 13368 $
 
 import os
 import datetime
@@ -320,7 +320,7 @@ class BaseFileAdmin(admin.ModelAdmin):
         if subFileName in TEXT_SUB_FILE_NAME:
             form = TextForm
             with open(fullPath, 'rb') as f:
-                data = f.read()
+                data = f.read().decode('utf-8')
             form.base_fields['content'].initial = data
         elif subFileName in IMAGE_SUB_FILE_NAME:
             form = ImageForm
