@@ -369,7 +369,7 @@ class SeleniumMixin(object):
     def _getEmail(time, emailFilePath=''):
         from django.conf import settings
         if not emailFilePath:
-            emailFilePath = f'{settings.BASE_DIR}/emailbox'
+            emailFilePath = f'{settings.BASE_DIR}/tests/emailbox'
 
         time = time.strftime("%Y%m%d-%H%M%S")
         content = None
