@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: AttachSettingsTest.py 11772 2019-11-01 08:50:14Z Andy $
+# $Id: AttachSettingsTest.py 13367 2021-12-24 04:53:31Z Mint $
 #
 # Copyright (c) 2016 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Andy $
-# $Date: 2019-11-01 16:50:14 +0800 (Fri, 01 Nov 2019) $
-# $Revision: 11772 $
+# $Author: Mint $
+# $Date: 2021-12-24 12:53:31 +0800 (週五, 24 十二月 2021) $
+# $Revision: 13367 $
 
 import os
 import warnings
@@ -175,8 +175,18 @@ class TestAttachSettings(TestCase):
             ],
         }
         
-        self.assertEqual(settingsContent['TEMPLATES'],
-                         templatesSettings['TEMPLATES'])
+        for i in ['BACKEND','APP_DIRS','OPTIONS']:
+            self.assertEqual(settingsContent['TEMPLATES'][0]['BACKEND'],
+                         templatesSettings['TEMPLATES'][0]['BACKEND'])
+        # sometimes there will error because of lowercase and uppercase dirs   
+        # to fox this, we combine all parameter seperatly
+        fixedSettingDirs = settingsContent['TEMPLATES'][0]['DIRS']
+        fixedTemplateDirs = templatesSettings['TEMPLATES'][0]['DIRS']
+        for i in range(len(fixedSettingDirs)):
+            fixedSettingDirs[i] = fixedSettingDirs[i].lower()
+        for i in range(len(fixedTemplateDirs)):
+            fixedTemplateDirs[i] = fixedTemplateDirs[i].lower()
+        self.assertEqual(fixedSettingDirs,fixedTemplateDirs)
         
     def testMissingTemplatesSettings(self):
         from django.conf import settings
@@ -245,8 +255,19 @@ class TestAttachSettings(TestCase):
             ],
         }
         
-        self.assertEqual(settingsContent['TEMPLATES'],
-                         templatesSettings['TEMPLATES'])
+        for i in ['BACKEND','APP_DIRS','OPTIONS']:
+            self.assertEqual(settingsContent['TEMPLATES'][0]['BACKEND'],
+                         templatesSettings['TEMPLATES'][0]['BACKEND'])
+        # sometimes there will error because of lowercase and uppercase dirs        
+        fixedSettingDirs = settingsContent['TEMPLATES'][0]['DIRS']
+        fixedTemplateDirs = templatesSettings['TEMPLATES'][0]['DIRS']
+        for i in range(len(fixedSettingDirs)):
+            fixedSettingDirs[i] = fixedSettingDirs[i].lower()
+        for i in range(len(fixedTemplateDirs)):
+            fixedTemplateDirs[i] = fixedTemplateDirs[i].lower()
+        self.assertEqual(fixedSettingDirs,fixedTemplateDirs)
+
+        
 
     def testHttpsSettings(self):
         settingsContent = TestAttachSettings.REQUIRED_SETTINGS.copy()
